#
# spec file for package SDL2_mixer
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           SDL2_mixer
%define lname	libSDL2_mixer-2_0-0
Version:        2.8.0
Release:        3.2
Summary:        SDL2 sound mixer library
License:        Zlib
Group:          Development/Libraries/C and C++
URL:            http://libsdl.org/projects/SDL_mixer/

#Git-Clone:     https://github.com/libsdl-org/SDL_mixer
Source:         https://github.com/libsdl-org/SDL_mixer/releases/download/release-%version/SDL2_mixer-%version.tar.gz
Source2:        https://github.com/libsdl-org/SDL_mixer/releases/download/release-%version/SDL2_mixer-%version.tar.gz.sig
Source3:        %name.keyring
Source4:        baselibs.conf
BuildRequires:  SDL2-devel >= 2.24
BuildRequires:  dos2unix
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(flac)
BuildRequires:  pkgconfig(fluidsynth)
BuildRequires:  pkgconfig(libmpg123)
BuildRequires:  pkgconfig(libxmp)
BuildRequires:  pkgconfig(opusfile)
BuildRequires:  pkgconfig(vorbis)
Suggests:       timidity

%description
A multichannel audio mixer. It supports four channels of 16-bit stereo
audio, plus a single channel of music, mixed by the MikMod MOD,
Timidity MIDI, and mpg123 MP3 libraries.

%package -n %lname
Summary:        Simple DirectMedia Layer 2 – Sound mixer library
Group:          System/Libraries
Provides:       SDL2_mixer = %version-%release

%description -n %lname
A multichannel audio mixer. It supports four channels of 16-bit stereo
audio, plus a single channel of music, mixed by the MikMod MOD,
Timidity MIDI, and mpg123 MP3 libraries.

%package devel
Summary:        Development files for the SDL2 sound mixer library
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
Obsoletes:      libSDL2_mixer-devel < %version-%release
Provides:       libSDL2_mixer-devel = %version-%release

%description devel
A multi-channel audio mixer. It supports 4 channels of 16-bit stereo
audio, plus a single channel of music, mixed by the MikMod MOD,
Timidity MIDI, and mpg123 MP3 libraries.

%prep
%autosetup -p1
dos2unix *.txt
rm -rf external

%build
# --disable-*-shared: Link, rather than dlopen
#
%configure \
	--disable-music-ogg-stb --enable-music-ogg-vorbis \
	--disable-music-flac-drflac --enable-music-flac-libflac \
	--disable-music-mp3-drmp3 --enable-music-mp3-mpg123 \
	--disable-music-mod-modplug --enable-music-mod-xmp \
	--disable-music-mod-xmp-shared \
	--disable-music-midi-fluidsynth-shared \
	--disable-music-ogg-shared \
	--disable-music-flac-shared \
	--disable-music-mp3-mpg123-shared \
	--disable-static
%make_build

%install
%make_install install-bin
rm -f "%buildroot/%_libdir"/*.la
# We have these debug tools in SDL_mixer-devel already
rm -f "%buildroot/%_bindir"/play*

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%license LICENSE.txt
%doc CHANGES.txt README.txt
%_libdir/libSDL2_mixer-2*.so.*

%files devel
%_includedir/SDL2/
%_libdir/libSDL2_mixer.so
%_libdir/pkgconfig/*.pc
%_libdir/cmake/

%changelog
* Sun Jul 28 2024 Jan Engelhardt <jengelh@inai.de>
- Reintroduce baselibs.conf [boo#1227467]
* Fri Feb  2 2024 Jan Engelhardt <jengelh@inai.de>
- Link to libmpg123 again
* Sun Jan 21 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.8
  * Added support for loading wavpack sound files, added support for
  loading classic console sound files using Game_Music_Emu
  * Added support for FLAC audio in Ogg containers
  * Added Mix_PauseAudio() to pause and resume all audio playback
  * Added Mix_GetNumTracks() and Mix_StartTrack() for managing
  tracks in GME files
* Tue Feb  7 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.6.3
  * Fixed tags memory leak in Opus music handling
* Sat Aug 20 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.6.2
  * Build updates for non-Linux platforms
* Mon Jul 18 2022 munix9@googlemail.com
- Update to release 2.6.1
  * This is a minor bug-fix release, fixing a packaging issue
    on Linux.
* Sat Jul  9 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.6.0
  * Added Mix_MasterVolume() for additional volume control over
    all channels
  * Update Mix_Init() return value to match documentation,
    including MIXER_INIT_* flags for already-initialized modules
  * Added Mix_HasMusicDecoder()
  * Memory leak fixes and F32 format support to fluidsynth player
  * Fixed distorted MIDI playback with FluidSynth if sample rate
    is out of library's limits
  * Added Mix_ModMusicJumpToOrder() for mod music formats
  * Fixes to ogg playback on big-endian devices
  * Added functions to get metadata information and loop point
    information (Mix_GetMusic*)
  * Extended support for WAV files
  * Allow rmid files be opened by native midi
  * Prevent clipping due to volume settings in modplug music
  * Added looping support for Opus, FLAC files
  * Improved OGG looping support
- Switch from libmodplug to libxmp as backend for tracker files
- Rename -devel subpackage based on SRPM name
- Drop 0001-use-after-free-fluidsynth.patch (merged)
- Drop baselibs.conf (no SDL2_mixer-dependent Tumbleweed packages
  themselves have baselibs).
* Thu Jan 21 2021 Tom Mbrt <tom.mbrt@googlemail.com>
- Add 0001-use-after-free-fluidsynth.patch to prevent
  fluidsynth >= 2.1.6 from crashing:
  https://hg.libsdl.org/SDL_mixer/rev/b0afe341a91d
* Tue Sep 15 2020 Jan Engelhardt <jengelh@inai.de>
- Demote Recommends to Suggests.
* Tue Mar  5 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.0.4
  * Removed smpeg support for mp3 music, now that it's replaced
    by libmpg123.
  * Fixed mp3 mad decoder to skip tags, which otherwise would lead
    to crashes.
  * Added support for Opus music playback using opusfile library.
- Update to version 2.0.3
  * Fixed regression where Mix_Init() would return 0 for available
    music formats.
- Remove patch:
  * SDL2_mixer-only-load-required-interfaces.patch (fixed by upstream)
* Sat Dec 23 2017 9@cirno.systems
- update to version 2.0.2
  * 24-bit and surround sound support for FLAC audio files
  * Updated for SDL 2.0.6 and newer
  * Support for MP3 playback using mpg123
  * Added Mix_OpenAudioDevice() to specify the audio device to open
- Add SDL2_mixer-only-load-required-interfaces.patch
  Prevents initializing decoders unnecessarily.
  Fixes an issue with applications that use the API incorrectly
  (due to misleading documentation).
- Build with libmpg123 where available
- Fix fluidsynth linking
* Sun Jan 10 2016 mailaender@opensuse.org
- update to version 2.0.1
  * Added support for 'smpl' format loop points in music WAV files
  * Fixed floating point exception in Mix_Volume()
  * Added support for loading MP3 files as sound chunks
* Thu Jan  8 2015 jengelh@inai.de
- Improve package summary and description. Drop --with-pic which
  is enabled implicitly anyway, remove redundant Requires.
* Wed Aug 28 2013 jengelh@inai.de
- Abstain from providing playmus and playwave in SDL2_mixer
  (they are already available through SDL(1)_mixer)
* Tue Aug 13 2013 jengelh@inai.de
- Some metadata spruce-up: add current URLs, softer wildcarding
  in the files list
* Tue Aug 13 2013 prusnak@opensuse.org
- created package (version 2.0.0) - based on SDL_mixer package
